@@ -34,14 +34,11 @@
 
 #include "CtrlOScope.h"
 
-#include <math.h>
+#include <cmath>
+#include <vector>
 
-/////////////////////////////////////////////////////////////////////////////
-// CtrlOScope
 CtrlOScope::CtrlOScope(wxWindow* parent, wxString xname, wxString yname)
     : wxControl(parent, -1, wxDefaultPosition, wxSize(300, 200)) {
-  m_fsampling = 0;
-
   m_bgColor.Set(0, 0, 0);
   m_plColor.Set(0, 128, 0);
   m_trColor.Set(192, 192, 0);
@@ -59,6 +56,8 @@ CtrlOScope::CtrlOScope(wxWindow* parent, wxString xname, wxString yname)
   m_YUnit = yname;
   m_XUnit = xname;
 
+  m_interp = LINE;
+
   m_NumberOfVerticals = 0;
 
   m_UserText = wxT("");
@@ -68,45 +67,34 @@ CtrlOScope::CtrlOScope(wxWindow* parent, wxString xname, wxString yname)
   Bind(wxEVT_SIZE, &CtrlOScope::OnSize, this);
   Bind(wxEVT_PAINT, &CtrlOScope::OnPaint, this);
   Bind(wxEVT_ERASE_BACKGROUND, &CtrlOScope::OnEraseBackground, this);
+}
 
-}  // CtrlOScope
+CtrlOScope::~CtrlOScope() {}
 
-/////////////////////////////////////////////////////////////////////////////
-CtrlOScope::~CtrlOScope() {}  // ~CtrlOScope
+void CtrlOScope::SetTrack1(wxArrayDouble const& ardbl) { m_points1 = ardbl; }
 
-void CtrlOScope::SetTrack1(wxArrayDouble& ardbl) { m_points1 = ardbl; }
+void CtrlOScope::SetTrack2(wxArrayDouble const& ardbl) { m_points2 = ardbl; }
 
-void CtrlOScope::SetTrack2(wxArrayDouble& ardbl) { m_points2 = ardbl; }
+void CtrlOScope::SetTrackX(wxArrayDouble const& ardbl) { m_pointsX = ardbl; }
 
-void CtrlOScope::SetTrackX(wxArrayDouble& ardbl) { m_pointsX = ardbl; }
+void CtrlOScope::SetInterp(CtrlOScope::Interpolation interp) { m_interp = interp; }
 
-/////////////////////////////////////////////////////////////////////////////
 void CtrlOScope::SetXRange(double dLower, double dUpper, int logrange) {
   m_MinXValue = dLower;
   m_MaxXValue = dUpper;
   m_LogX = logrange;
-}  // SetRange
+}
 
 void CtrlOScope::SetYRange(double dLower, double dUpper, int logrange) {
   m_MinYValue = dLower;
   m_MaxYValue = dUpper;
   m_LogY = logrange;
-}  // SetRange
-
-void CtrlOScope::SetFsample(int fsampling) { m_fsampling = fsampling; }
-
-void CtrlOScope::SetXUnits(wxString WXUNUSED(string), wxString WXUNUSED(XMin),
-                           wxString WXUNUSED(XMax)) {}  // SetXUnits
-
-void CtrlOScope::SetYUnits(wxString WXUNUSED(string), wxString WXUNUSED(YMin),
-                           wxString WXUNUSED(YMax)) {}  // SetYUnits
-
-void CtrlOScope::OnPaint(wxPaintEvent& WXUNUSED(event)) {
-  wxPaintDC dc(this);  // device context for painting
-  PaintAll(dc);
 }
 
-void CtrlOScope::PaintAll(wxDC& dc) {
+void CtrlOScope::OnSize(wxSizeEvent& event) { event.Skip(); }
+
+void CtrlOScope::OnPaint(wxPaintEvent& WXUNUSED(event)) {
+  wxPaintDC cdc(this);  // device context for painting
   // here will be the Double Buffer
   wxRect rec = GetClientRect();
 
@@ -118,12 +106,36 @@ void CtrlOScope::PaintAll(wxDC& dc) {
 
   PaintGraph(*memDC);
 
-  dc.Blit(rec.x, rec.y, rec.width, rec.height, memDC, 0, 0, wxCOPY);
+  cdc.Blit(rec.x, rec.y, rec.width, rec.height, memDC, 0, 0, wxCOPY);
 
   delete bmpBlit;
   delete memDC;
 }
 
+inline double sinc(double x) {
+  if (x == 0.0)
+    return 1.0;
+  else
+    return sin(x * M_PI) / (x * M_PI);
+}
+
+static void sinc_interpolate(wxArrayDouble& xdata, wxArrayDouble& ydata, wxArrayDouble& xpoints,
+                             wxArrayDouble& ypoints) {
+  size_t size = xpoints.size() - 1;
+  auto srate = size / xpoints[size];
+  for (size_t j = 0; j < size * 5; j++) {
+    size_t i = 0;
+    double sum = 0.0;
+    double tim = 1.0 * j / (srate * 5);
+    while (i <= size) {
+      sum += sinc((tim - xpoints[i]) * srate) * ypoints[i];
+      i++;
+    }
+    xdata.Add(tim);
+    ydata.Add(sum);
+  }
+}
+
 void CtrlOScope::PaintGraph(wxDC& dc) {
   wxRect rec = GetClientRect();
   wxString bla;
@@ -143,7 +155,7 @@ void CtrlOScope::PaintGraph(wxDC& dc) {
 
   /* spocitat vysku pisma pro spodni odstup a sirky pto odstup zleva */
   /* calculate space for legend */
-  if (m_YUnit != wxT("")) {
+  if (!m_YUnit.empty()) {
     dc.GetTextExtent(m_YUnit, &tw, &th);
     udist = tw;
   }
@@ -155,7 +167,7 @@ void CtrlOScope::PaintGraph(wxDC& dc) {
   if (ldist < (udist + tw + 8)) {
     ldist = udist + tw + 8;
   }
-  if (m_XUnit != wxT("")) {
+  if (!m_XUnit.empty()) {
     dc.GetTextExtent(_T("T"), &tw, &th);
     udist = th;
   }
@@ -185,7 +197,7 @@ void CtrlOScope::PaintGraph(wxDC& dc) {
   if (m_LogX) {
     /* draw vertical lines with log distance */
     xstep = (rec.width - ldist - rdist) / log10(m_MaxXValue / m_MinXValue);
-    if (m_MinXValue < 1) m_MinXValue = 1; // avoid log10(0) and rounding errors
+    if (m_MinXValue < 1) m_MinXValue = 1;  // avoid log10(0) and rounding errors
     int decade = log10(m_MinXValue);
     double freq = m_MinXValue;
     while (freq <= m_MaxXValue) {
@@ -211,7 +223,6 @@ void CtrlOScope::PaintGraph(wxDC& dc) {
     /* draw vertical lines with linear distance */
     xstep = (double)(rec.width - ldist - rdist) / m_NumberOfVerticals;
     for (int i = 0; i <= m_NumberOfVerticals; i++) {
-      /* kresli vsechny cary */
       dc.DrawLine((int)(ldist + xstep * i), tdist, (int)(ldist + xstep * i), rec.height - bdist);
       double cl = m_MinXValue + (m_MaxXValue - m_MinXValue) * i / m_NumberOfVerticals;
       int clk = cl / 1000;
@@ -239,7 +250,8 @@ void CtrlOScope::PaintGraph(wxDC& dc) {
   /* zobrazit body - draw data */
   if (m_pointsX.GetCount() > 0) {
     // limit drawing region to the graph
-    dc.SetClippingRegion(ldist, tdist, rec.width - ldist - rdist, rec.height - tdist - bdist);
+    dc.SetClippingRegion(ldist, tdist, rec.width - ldist - rdist + 1,
+                         rec.height - tdist - bdist + 1);
 
     size_t ilow = 0, ihigh = 0;
     // iterate though all X points in the data
@@ -255,48 +267,57 @@ void CtrlOScope::PaintGraph(wxDC& dc) {
     if ((int)ihigh < ((int)m_pointsX.GetCount() - 1)) ihigh++;
 
     // left channel
-    PaintTrack(dc, ilow, ihigh, xstep, m_trColor, m_points1);
+    if (m_interp == SINC) {
+      wxArrayDouble xdata;
+      wxArrayDouble ydata;
+      sinc_interpolate(xdata, ydata, m_pointsX, m_points1);
+      PaintTrack(dc, ilow, ihigh * 5 - 1, xstep, m_trColor, xdata, ydata);
+      xdata.Clear();
+      ydata.Clear();
+    } else {
+      PaintTrack(dc, ilow, ihigh, xstep, m_trColor, m_pointsX, m_points1);
+    }
 
     // right channel
-    PaintTrack(dc, ilow, ihigh, xstep, m_tr2Color, m_points2);
+    if (m_interp == SINC) {
+      wxArrayDouble xdata;
+      wxArrayDouble ydata;
+      sinc_interpolate(xdata, ydata, m_pointsX, m_points2);
+      PaintTrack(dc, ilow, ihigh * 5 - 1, xstep, m_tr2Color, xdata, ydata);
+      xdata.Clear();
+      ydata.Clear();
+    } else {
+      PaintTrack(dc, ilow, ihigh, xstep, m_tr2Color, m_pointsX, m_points2);
+    }
   }
 }
 
-void CtrlOScope::PaintTrack(wxDC& dc, size_t from, size_t to, double xstep, wxColor color,
-                            wxArrayDouble& points) {
+void CtrlOScope::PaintTrack(wxDC& dc, size_t from, size_t to, double xstep, const wxColor& color,
+                            wxArrayDouble& xpoints, wxArrayDouble& ypoints) {
   dc.SetPen(wxPen(color, 1, wxPENSTYLE_SOLID));
-  int lastx = 0, lasty = 0, xpos = 0;
   wxRect rec = GetClientRect();
+  std::vector<wxPoint> pv;
   // iterate trough the data points in range
   for (size_t i = from; i <= to; i++) {
+    int xpos;
     if (m_LogX)
-      xpos = (int)ldist + xstep * log10(m_pointsX.Item(i) / m_MinXValue);
+      xpos = ldist + xstep * log10(m_pointsX.Item(i) / m_MinXValue);
     else
-      xpos = ldist + m_pointsX.Item(i) * xstep * m_NumberOfVerticals / (m_MaxXValue - m_MinXValue);
+      xpos = ldist + xpoints.Item(i) * xstep * m_NumberOfVerticals / (m_MaxXValue - m_MinXValue);
     // find the point in the graph and limit to the graph area
-    double ydatapoint = points.Item(i);
+    double ydatapoint = ypoints.Item(i);
     if (ydatapoint > m_MaxYValue) ydatapoint = m_MaxYValue;
     if (ydatapoint < m_MinYValue) ydatapoint = m_MinYValue;
     double ypoint =
         rec.height - bdist -
         (rec.height - bdist - tdist) * (ydatapoint - m_MinYValue) / (m_MaxYValue - m_MinYValue);
-    if (lastx == 0) {
-      dc.DrawPoint((int)(xpos), (int)(ypoint));
-    } else {
-      dc.DrawLine(lastx, lasty, (int)(xpos), (int)(ypoint));
-    }
-    lastx = (int)(xpos);
-    lasty = (int)(ypoint);
+    wxPoint pt = {xpos, (int)ypoint};
+    pv.push_back(pt);
   }
+  if (pv.size() > 1) dc.DrawLines(pv.size(), &pv[0]);
 
   if (wxT("") != m_UserText) {
     dc.SetTextForeground(m_whColor);
     dc.DrawText(m_UserText, m_UserTextPosX, m_UserTextPosY);
   }
 }
-
-/////////////////////////////////////////////////////////////////////////////
-void CtrlOScope::OnSize(wxSizeEvent& event)  // UINT nType, int cx, int cy)
-{
-  event.Skip();
-}  // OnSize
