@@ -27,17 +27,9 @@
  * along with this program.  If not, see <https://www.gnu.org/licenses/>.
  */
 
-#if defined(__GNUG__) && !defined(NO_GCC_PRAGMA)
-#pragma implementation "dlg_audiointerface.h"
-#endif
-
 // For compilers that support precompilation, includes "wx/wx.h".
 #include "wx/wxprec.h"
 
-#ifdef __BORLANDC__
-#pragma hdrstop
-#endif
-
 #ifndef WX_PRECOMP
 #include "wx/wx.h"
 #endif
@@ -55,30 +47,25 @@
  * AudioInterfaceDialog type definition
  */
 
-IMPLEMENT_DYNAMIC_CLASS(AudioInterfaceDialog, wxDialog)
+wxIMPLEMENT_DYNAMIC_CLASS(AudioInterfaceDialog, wxDialog);
 
 /*!
  * AudioInterfaceDialog event table definition
  */
 
-BEGIN_EVENT_TABLE(AudioInterfaceDialog, wxDialog)
-
-////@begin AudioInterfaceDialog event table entries
-////@end AudioInterfaceDialog event table entries
-EVT_CHOICE(ID_OUTDEV_CHO, AudioInterfaceDialog::OnChoiceChanged)
-EVT_CHOICE(ID_INDEV_CHO, AudioInterfaceDialog::OnChoiceChanged)
-
-END_EVENT_TABLE()
+wxBEGIN_EVENT_TABLE(AudioInterfaceDialog, wxDialog)
+  EVT_CHOICE(ID_OUTDEV_CHO, AudioInterfaceDialog::OnChoiceChanged)
+  EVT_CHOICE(ID_INDEV_CHO, AudioInterfaceDialog::OnChoiceChanged)
+wxEND_EVENT_TABLE()
 
 /*!
  * AudioInterfaceDialog constructors
  */
 
-AudioInterfaceDialog::AudioInterfaceDialog() { Init(); }
+AudioInterfaceDialog::AudioInterfaceDialog() {}
 
 AudioInterfaceDialog::AudioInterfaceDialog(wxWindow* parent, wxWindowID id, const wxString& caption,
                                            const wxPoint& pos, const wxSize& size, long style) {
-  Init();
   Create(parent, id, caption, pos, size, style);
 }
 
@@ -101,14 +88,6 @@ bool AudioInterfaceDialog::Create(wxWindow* parent, wxWindowID id, const wxStrin
   return true;
 }
 
-/*!
- * Member initialisation
- */
-
-void AudioInterfaceDialog::Init() {
-  ////@begin AudioInterfaceDialog member initialisation
-  ////@end AudioInterfaceDialog member initialisation
-}
 /*!
  * Control creation for AudioInterfaceDialog
  */
@@ -252,7 +231,7 @@ void AudioInterfaceDialog::SetDevices(RWAudioDevList devreclist, RWAudioDevList
 
         if (srateplay == sraterec) {
           if (srateplay == m_freq) cfreq = p_cho->GetCount();
-          p_cho->Append(wxString::Format(wxT("%d "), srateplay));
+          p_cho->Append(wxString::Format(wxT("%u "), srateplay));
         }
       }
     }
@@ -327,7 +306,7 @@ void AudioInterfaceDialog::OnChoiceChanged(wxCommandEvent& WXUNUSED(event)) {
 
         if (srateplay == sraterec) {
           if (srateplay == m_freq) cfreq = p_cho->GetCount();
-          p_cho->Append(wxString::Format(wxT("%d "), srateplay));
+          p_cho->Append(wxString::Format(wxT("%u "), srateplay));
         }
       }
     }
