@@ -30,10 +30,6 @@
 #ifndef _DLG_AUDIOINTERFACE_H_
 #define _DLG_AUDIOINTERFACE_H_
 
-#if defined(__GNUG__) && !defined(NO_GCC_PRAGMA)
-#pragma interface "dlg_audiointerface.h"
-#endif
-
 /*!
  * Includes
  */
@@ -81,8 +77,8 @@ struct AIStreamSettings {
 };
 
 class AudioInterfaceDialog : public wxDialog {
-  DECLARE_DYNAMIC_CLASS(AudioInterfaceDialog)
-  DECLARE_EVENT_TABLE()
+  wxDECLARE_DYNAMIC_CLASS(AudioInterfaceDialog);
+  wxDECLARE_EVENT_TABLE();
 
   RWAudioDevList m_DevRecList;
   RWAudioDevList m_DevPlayList;
@@ -105,9 +101,6 @@ class AudioInterfaceDialog : public wxDialog {
               const wxSize& size = SYMBOL_AUDIOINTERFACEDIALOG_SIZE,
               long style = SYMBOL_AUDIOINTERFACEDIALOG_STYLE);
 
-  /// Initialises member variables
-  void Init();
-
   /// Creates the controls and sizers
   void CreateControls();
 
